==> react-build-cli-0.0.25.tgz: package/src/getConfig.ts <==
import { PluginItem } from '@babel/core';
import { Output, Entry } from 'webpack';
import { ProxyConfigMap, ProxyConfigArray } from 'webpack-dev-server';
import { Options } from './start';
import getWebpackConfig, { Configuration } from './getWebpackConfig';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import utils from './utils';
import paths from './paths';

export interface RcbConfig {
    host?: string;
    port?: number;
    proxy?: ProxyConfigMap | ProxyConfigArray;
    mock?: MockConfig;
    babelPresets?: PluginItem[] | null;
    babelPlugins?: PluginItem[] | null;
    output?: Output;
    entry?: Entry;
    devtool?: Configuration['devtool'];
    alias?: { [key: string]: string }; // alias路径
    open?: boolean; // 是否打开浏览器
    webpackPluginConfig?: HtmlWebpackPlugin.Options; // html-webpack-plugin 配置
    webpack?: Configuration; // webpack配置
    transpileDependencies?: any[]; // 额外需要转译的库
    additionalModulePaths?: any[]; // 额外连接库
    esModuleImage?: boolean; // 图片是否开启es模块
}

export interface MockConfig {
    rootDir: string;
    api: string;
    whiteList: string[];
}

const defaultMockConfig = {
    rootDir: 'mock', // mock文件的根目录
    api: '/api', // 请求的前缀
    whiteList: [] // 放行的接口
};

export function getRcbConfig(): RcbConfig {
    try {
        return utils.requireModule(paths.getResolvePath('rcb.config.js'));
    }
    catch (e) {
        return {};
    }
}

export function getMockConfig(rcb: RcbConfig) {
    try {
        const mockrc = require(paths.getResolvePath('.mockrc.json'));

        return Object.assign({}, defaultMockConfig, rcb.mock, mockrc);
    }
    catch (e) {
        return Object.assign({}, defaultMockConfig);
    }
}

function getBabelConfig() {
    // TODO
    return {};
}

export default function getExtraConfig(options?: Options) {
    const rcb = getRcbConfig();
    const mockConfig = getMockConfig(rcb);
    rcb.mock = mockConfig;
    return {
        webpack: getWebpackConfig(rcb, options),
        babel: getBabelConfig(),
        rcb
    };
}

==> react-build-cli-0.1.0.tgz: package/src/getConfig.ts <==
import { PluginItem } from '@babel/core';
import { Entry } from 'webpack';
import { ProxyConfigMap, ProxyConfigArray } from 'webpack-dev-server';
import { Options } from './start';
import getWebpackConfig, { Configuration } from './getWebpackConfig';
import utils from './utils';
import paths from './paths';

export interface RcbConfig {
    host?: string;
    port?: number;
    proxy?: ProxyConfigMap | ProxyConfigArray;
    mock?: MockConfig;
    babelPresets?: PluginItem[] | null;
    babelPlugins?: PluginItem[] | null;
    output?: any; // ?type
    entry?: Entry;
    devtool?: Configuration['devtool'];
    alias?: { [key: string]: string }; // alias路径
    open?: boolean; // 是否打开浏览器
    webpackPluginConfig?: any; // ?type webpack plugin
    webpack?: Configuration; // webpack配置
    transpileDependencies?: any[]; // 额外需要转译的库
    additionalModulePaths?: any[]; // 额外连接库
    esModuleImage?: boolean; // 图片是否开启es模块
    moduleFederationPlugin?: any
}

export interface MockConfig {
    rootDir: string;
    api: string;
    whiteList: string[];
}

const defaultMockConfig = {
    rootDir: 'mock', // mock文件的根目录
    api: '/api', // 请求的前缀
    whiteList: [] // 放行的接口
};

export function getRcbConfig(): RcbConfig {
    try {
        return utils.requireModule(paths.getResolvePath('rcb.config.js'));
    }
    catch (e) {
        return {};
    }
}

export function getMockConfig(rcb: RcbConfig) {
    try {
        const mockrc = require(paths.getResolvePath('.mockrc.json'));

        return Object.assign({}, defaultMockConfig, rcb.mock, mockrc);
    }
    catch (e) {
        return Object.assign({}, defaultMockConfig);
    }
}

function getBabelConfig() {
    // TODO
    return {};
}

export default function getExtraConfig(options?: Options) {
    const rcb = getRcbConfig();
    const mockConfig = getMockConfig(rcb);
    rcb.mock = mockConfig;
    return {
        webpack: getWebpackConfig(rcb, options),
        babel: getBabelConfig(),
        rcb
    };
}
